@@ -47,6 +47,7 @@ class Fan(Device):
         group_address_speed_state: GroupAddressesType | None = None,
         group_address_oscillation: GroupAddressesType | None = None,
         group_address_oscillation_state: GroupAddressesType | None = None,
+        sync_state: bool | int | float | str = True,
         device_updated_cb: DeviceCallbackType | None = None,
         max_step: int | None = None,
     ):
@@ -62,6 +63,7 @@ class Fan(Device):
                 xknx,
                 group_address_speed,
                 group_address_speed_state,
+                sync_state=sync_state,
                 device_name=self.name,
                 feature_name="Speed",
                 after_update_cb=self.after_update,
@@ -71,6 +73,7 @@ class Fan(Device):
                 xknx,
                 group_address_speed,
                 group_address_speed_state,
+                sync_state=sync_state,
                 device_name=self.name,
                 feature_name="Speed",
                 after_update_cb=self.after_update,
@@ -82,6 +85,7 @@ class Fan(Device):
             xknx,
             group_address_oscillation,
             group_address_oscillation_state,
+            sync_state=sync_state,
             device_name=self.name,
             feature_name="Oscillation",
             after_update_cb=self.after_update,
