@@ -33,6 +33,7 @@ class Switch(Device):
         group_address: GroupAddressesType | None = None,
         group_address_state: GroupAddressesType | None = None,
         respond_to_read: bool = False,
+        sync_state: bool | int | float | str = True,
         invert: bool = False,
         reset_after: float | None = None,
         device_updated_cb: DeviceCallbackType | None = None,
@@ -47,6 +48,7 @@ class Switch(Device):
             xknx,
             group_address,
             group_address_state,
+            sync_state=sync_state,
             invert=invert,
             device_name=self.name,
             after_update_cb=self.after_update,
@@ -65,11 +67,6 @@ class Switch(Device):
                 pass
         super().__del__()
 
-    @property
-    def unique_id(self) -> str | None:
-        """Return unique id for this device."""
-        return f"{self.switch.group_address}"
-
     @property
     def state(self) -> bool | None:
         """Return the current switch state of the device."""
