@@ -7,25 +7,26 @@ from __future__ import annotations
 
 from xknx.exceptions import ConversionError
 
-from .dpt import DPTBase
+from .dpt import DPTNumeric
 
 
-class DPT2ByteFloat(DPTBase):
+class DPT2ByteFloat(DPTNumeric):
     """
     Abstraction for KNX 2 Octet Floating Point Numbers.
 
     DPT 9.***
     """
 
-    value_min = -671088.64
-    value_max = 670760.96
     dpt_main_number = 9
     dpt_sub_number: int | None = None
     value_type = "2byte_float"
     unit = ""
-    resolution = 0.01
     payload_length = 2
 
+    value_min = -671088.64
+    value_max = 670760.96
+    resolution = 0.01
+
     @classmethod
     def from_knx(cls, raw: tuple[int, ...]) -> float:
         """Parse/deserialize from KNX/IP raw data."""
@@ -87,84 +88,91 @@ class DPT2ByteFloat(DPTBase):
 class DPTTemperature(DPT2ByteFloat):
     """DPT 9.001 DPT_Value_Temp."""
 
-    value_min = -273
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 1
     value_type = "temperature"
     unit = "°C"
     ha_device_class = "temperature"
 
+    value_min = -273
+    value_max = 670760
+
 
 class DPTTemperatureDifference2Byte(DPT2ByteFloat):
     """DPT 9.002 DPT_Value_Tempd."""
 
-    value_min = -670760
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 2
     value_type = "temperature_difference_2byte"
     unit = "K"
     ha_device_class = "temperature"
 
+    value_min = -670760
+    value_max = 670760
+
 
 class DPTTemperatureA(DPT2ByteFloat):
     """DPT 9.003 DPT_Value_Tempa."""
 
-    value_min = -670760
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 3
     value_type = "temperature_a"
     unit = "K/h"
 
+    value_min = -670760
+    value_max = 670760
+
 
 class DPTLux(DPT2ByteFloat):
     """DPT 9.004 DPT_Value_Lux."""
 
-    value_min = 0
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 4
     value_type = "illuminance"
     unit = "lx"
     ha_device_class = "illuminance"
 
+    value_min = 0
+    value_max = 670760
+
 
 class DPTWsp(DPT2ByteFloat):
     """DPT 9.005 DPT_Value_Ws Speed (m/s)."""
 
-    value_min = 0
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 5
     value_type = "wind_speed_ms"
     unit = "m/s"
 
+    value_min = 0
+    value_max = 670760
+
 
 class DPTPressure2Byte(DPT2ByteFloat):
     """DPT 9.006 DPT_Value_Pres (Pa)."""
 
-    value_min = 0
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 6
     value_type = "pressure_2byte"
     unit = "Pa"
     ha_device_class = "pressure"
 
+    value_min = 0
+    value_max = 670760
+
 
 class DPTHumidity(DPT2ByteFloat):
     """DPT 9.007 DPT_Value_Humidity."""
 
-    value_min = 0
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 7
     value_type = "humidity"
     unit = "%"
     ha_device_class = "humidity"
 
+    value_min = 0
+    value_max = 670760
+
 
 class DPTPartsPerMillion(DPT2ByteFloat):
     """DPT 9.008 DPT_Value_parts/million."""
@@ -178,24 +186,26 @@ class DPTPartsPerMillion(DPT2ByteFloat):
 class DPTTime1(DPT2ByteFloat):
     """DPT 9.010 DPT_Value_Time1 (s)."""
 
-    value_min = -670760
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 10
     value_type = "time_1"
     unit = "s"
 
+    value_min = -670760
+    value_max = 670760
+
 
 class DPTTime2(DPT2ByteFloat):
     """DPT 9.011 DPT_Value_Time2 (ms)."""
 
-    value_min = -670760
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 11
     value_type = "time_2"
     unit = "ms"
 
+    value_min = -670760
+    value_max = 670760
+
 
 class DPTVoltage(DPT2ByteFloat):
     """DPT 9.020 DPT_Value_Voltage."""
@@ -255,36 +265,39 @@ class DPTVolumeFlow(DPT2ByteFloat):
 class DPTRainAmount(DPT2ByteFloat):
     """DPT 9.026 DPT_Rain_Amount (l/m²)."""
 
-    value_min = -671088.64
-    value_max = 670760.96
     dpt_main_number = 9
     dpt_sub_number = 26
     value_type = "rain_amount"
     unit = "l/m²"
 
+    value_min = -671088.64
+    value_max = 670760.96
+
 
 class DPTTemperatureF(DPT2ByteFloat):
     """DPT 9.027 DPT_Value_Temp_F."""
 
-    value_min = -459.6
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 27
     value_type = "temperature_f"
     unit = "°F"
     ha_device_class = "temperature"
 
+    value_min = -459.6
+    value_max = 670760
+
 
 class DPTWspKmh(DPT2ByteFloat):
     """DPT 9.028 DPT_Value_Wsp_kmh Speed (km/h)."""
 
-    value_min = 0
-    value_max = 670760
     dpt_main_number = 9
     dpt_sub_number = 28
     value_type = "wind_speed_kmh"
     unit = "km/h"
 
+    value_min = 0
+    value_max = 670760
+
 
 class DPTEnthalpy(DPT2ByteFloat):
     """DPT 9.? 2-byte float value (with unit)."""
