@@ -24,6 +24,7 @@ class RemoteValueColorRGBW(RemoteValue[DPTArray, Tuple[int, int, int, int]]):
         xknx: XKNX,
         group_address: GroupAddressesType | None = None,
         group_address_state: GroupAddressesType | None = None,
+        sync_state: bool | int | float | str = True,
         device_name: str | None = None,
         feature_name: str = "Color RGBW",
         after_update_cb: AsyncCallbackType | None = None,
@@ -33,6 +34,7 @@ class RemoteValueColorRGBW(RemoteValue[DPTArray, Tuple[int, int, int, int]]):
             xknx,
             group_address,
             group_address_state,
+            sync_state=sync_state,
             device_name=device_name,
             feature_name=feature_name,
             after_update_cb=after_update_cb,
