@@ -23,6 +23,7 @@ class RemoteValueScaling(RemoteValue[DPTArray, int]):
         xknx: XKNX,
         group_address: GroupAddressesType | None = None,
         group_address_state: GroupAddressesType | None = None,
+        sync_state: bool | int | float | str = True,
         device_name: str | None = None,
         feature_name: str = "Value",
         after_update_cb: AsyncCallbackType | None = None,
@@ -34,6 +35,7 @@ class RemoteValueScaling(RemoteValue[DPTArray, int]):
             xknx,
             group_address,
             group_address_state,
+            sync_state=sync_state,
             device_name=device_name,
             feature_name=feature_name,
             after_update_cb=after_update_cb,
