@@ -32,6 +32,7 @@ class RemoteValueSetpointShift(RemoteValue[DPTArray, float]):
         xknx: XKNX,
         group_address: GroupAddressesType | None = None,
         group_address_state: GroupAddressesType | None = None,
+        sync_state: bool | int | float | str = True,
         device_name: str | None = None,
         after_update_cb: AsyncCallbackType | None = None,
         setpoint_shift_mode: SetpointShiftMode | None = None,
@@ -42,6 +43,7 @@ class RemoteValueSetpointShift(RemoteValue[DPTArray, float]):
             xknx,
             group_address,
             group_address_state,
+            sync_state=sync_state,
             device_name=device_name,
             feature_name="Setpoint shift value",
             after_update_cb=after_update_cb,
